@@ -1,24 +1,20 @@
 """ imports for AindModel subclasses
 """
 
-__version__ = "0.3.8"
+__version__ = "0.3.10"
 
 
-from .data_description import (
-    DataDescription,
-    DerivedDataDescription,
-    RawDataDescription,
-    Funding,
-)
+from .data_description import (DataDescription, DerivedDataDescription,
+                               Funding, RawDataDescription)
 from .ephys.ephys_rig import EphysRig
 from .ephys.ephys_session import EphysSession
 from .imaging.acquisition import Acquisition, Axis
 from .imaging.instrument import Instrument
+from .ophys.ophys_rig import OphysRig
+from .ophys.ophys_session import OphysSession
 from .procedures import Procedures
 from .processing import DataProcess, Processing
 from .subject import LightCycle, Subject
-from .ophys.ophys_rig import OphysRig
-from .ophys.ophys_session import OphysSession
 
 __all__ = [
     "DataDescription",
