@@ -4,7 +4,7 @@ from __future__ import annotations
 
 from datetime import date, time
 from enum import Enum
-from typing import Optional, List
+from typing import List, Optional
 
 from pydantic import Field
 
